Coverage report

File | function |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src / qutip_sampler / __init__.py | (no function) |  | 2 | 0 | 0 |  | 100%
src / qutip_sampler / samplers.py | _operator_on_qubit |  | 3 | 0 | 0 |  | 100%
src / qutip_sampler / samplers.py | _build_ising_hamiltonian |  | 15 | 0 | 0 |  | 100%
src / qutip_sampler / samplers.py | _build_transverse_hamiltonian |  | 4 | 0 | 0 |  | 100%
src / qutip_sampler / samplers.py | _initial_state |  | 2 | 0 | 0 |  | 100%
src / qutip_sampler / samplers.py | _sample_from_state |  | 6 | 0 | 0 |  | 100%
src / qutip_sampler / samplers.py | _anneal |  | 7 | 0 | 0 |  | 100%
src / qutip_sampler / samplers.py | QuTipSampler.__init__ |  | 4 | 0 | 0 |  | 100%
src / qutip_sampler / samplers.py | QuTipSampler.parameters |  | 1 | 0 | 0 |  | 100%
src / qutip_sampler / samplers.py | QuTipSampler.properties |  | 1 | 0 | 0 |  | 100%
src / qutip_sampler / samplers.py | QuTipSampler._resolve |  | 1 | 0 | 0 |  | 100%
src / qutip_sampler / samplers.py | QuTipSampler.sample_ising |  | 12 | 0 | 0 |  | 100%
src / qutip_sampler / samplers.py | QuTipSampler.sample_qubo |  | 2 | 0 | 0 |  | 100%
src / qutip_sampler / samplers.py | QuTipSampler.sample |  | 3 | 0 | 0 |  | 100%
src / qutip_sampler / samplers.py | (no function) |  | 22 | 0 | 0 |  | 100%
Total |  |  | 85 | 0 | 0 |  | 100%

No items found using the specified filter.